*cd c:\users\ash\dropbox\riksveg\replicatio

set more off

use dta\maindata, clear

* Drop Oslo and Bergen districts, and Vestfold 2013 (many missing hometowns) * 
drop if districtid==3|districtid==13|districtid==7&year==2013

* Keep only seven main parties
keep if main==1

* Tag the first candidate from the hometown among top 5 or 10, if complete hometown info *
foreach rank in 5 10 {
egen complete_top`rank'=total(hometownID!=.&rank<=`rank'), by(year districtid party)
egen top`rank'=tag(districtid year party hometownID) if rank<=`rank'&complete_top`rank'==`rank'
}

* Number of different hometowns among top candidates *
collapse (sum) mun_top5=top5 mun_top10=top10, by(districtid party year)
gen cnr=districtid
recode mun_top5 mun_top10 (0=.) /* 0 = incomplete hometown info */

* Matching with expected number of different hometowns *
merge m:1 cnr year using dta\sampling_top10.dta, keep(match master)
drop _merge
gen mun_exp_top10=municipalities
drop municipalities
merge m:1 cnr year using dta\sampling_top5.dta, keep(match master)
drop _merge
gen mun_exp_top5=municipalities
drop municipalities

* Reshaping to make separate obs. for top 5 and top 10 *
reshape long mun_ mun_exp_, i(districtid party year) j(sample) string
rename *_ *


local lab_dna "Labor Party"
local lab_sp "Center Party"
local lab_krf "Christian Democratic Party"
local lab_h "Conservative Party"

* Values on the 45 degree line *
foreach var in x y {
gen `var'45=0 if _n==1
replace `var'45=5 if _n==2
replace `var'45=10 if _n==3
}

* Scatterplots by party *
foreach party in dna sp h krf sv frp v {

twoway (scatter mun mun_exp if sample=="top5"&party=="`party'" , msymbol(Oh) mcolor(black) msize(small)) (line x45 y45 if _n<=2, lcolor(black) lpattern(shortdash)), ylabel(0(1)5) xlabel(0(1)5) legend(off) subtitle(`lab_`party'') ytitle("Number of hometowns with a candidate") xtitle("Expected number of hometowns with a candidate") graphregion(color(white))
graph save Fig\gph\ListBalance_top5_`party'.gph, replace

twoway (scatter mun mun_exp if sample=="top10"&party=="`party'", msymbol(Oh) mcolor(black) msize(small)) (line x45 y45, lcolor(black) lpattern(shortdash)), ylabel(0(2)10) xlabel(0(2)10) legend(off) subtitle(`lab_`party'') ytitle("Number of hometowns with a candidate") xtitle("Expected number of hometowns with a candidate") graphregion(color(white))
graph save Fig\gph\ListBalance_top10_`party'.gph, replace

}

graph combine Fig\gph\ListBalance_top10_dna.gph Fig\gph\ListBalance_top10_sp.gph Fig\gph\ListBalance_top10_krf.gph Fig\gph\ListBalance_top10_h.gph, ///
rows(2) ysize(5.2) iscale(*0.7) graphregion(color(white))
*graph export ..\figures\ListBalance10.pdf, replace
*graph export ..\figures\ListBalance10.png, replace
graph export Fig\Fig1.pdf, replace

graph combine Fig\gph\ListBalance_top5_dna.gph Fig\gph\ListBalance_top5_sp.gph Fig\gph\ListBalance_top5_krf.gph Fig\gph\ListBalance_top5_h.gph, ///
rows(2) ysize(5.2) iscale(*0.7) graphregion(color(white))
*graph export ..\figures\ListBalance5.pdf, replace
*graph export ..\figures\ListBalance5.png, replace
graph export Fig\FigA2.pdf, replace
