*cd c:\users\ash\dropbox\riksveg\replication


use dta\maindata, clear


*******************************************************************************
*** INTRODUCTORY CODE. NEEDS TO BE RUN BEFORE RUNNING CODE GENERATING EACH ****
*************************** FIGURE AND TABLE **********************************
*******************************************************************************


* Drop Oslo and Bergen districts, and Vestfold 2013 (many missing hometowns) * 
drop if districtid==3|districtid==13|districtid==7&year==2013

keep if sample_RD==1

* Drop if municipality merges to get consistent statistics of local party support at t+4
drop if merger==1|(districtid==12&year==1969)

rename (meterCAP_prev meterCAP_curr meterCAP_next ld_govempl d_govempl d2_govempl l_cgfund_inv cgfund_inv f_cgfund_inv) ///
(road_prev road_curr road_next govempl_prev govempl_curr govempl_next funding_prev funding_curr funding_next)

* 1st and 2nd tier seats
gen margwin=seat==1&margin>0&margin!=.
gen utjevn=seat==1&margin<0 

* Number of electable candidates (marginal or safe) *
egen electable_party_knr=total(margin>-0.05&margin!=.|margin==.&seat==1), by(hometownID party year)
egen electable_knr=total(margin>-0.05&margin!=.|margin==.&seat==1), by(hometownID year)

* Keep only marginal candidates for analysis *
drop if margin==.

* Party support relative to the rest of the district, and change in this *
foreach var in support turnout {
gen `var'_diff=`var'-`var'_district
gen `var'_diff_next=`var'_next-`var'_district_next
gen `var'_diff_change=`var'_diff_next-`var'_diff
}

* Leftwing parties *
gen Left=party=="nkp"|party=="sv"|party=="dna"

* Covariates for RD regressions *
gen margin_margwin=margin*margwin 
gen d89=year>=1989
gen d05=year>=2005 
foreach var in party year district rank {
qui tab `var', gen(d_`var')
}

lab var margwin "1st tier seat"
lab var utjevn "2nd tier seat"
lab var seat "1st or 2nd tier seat"

* Triangular or rectangular kernel weighting *
gen weight1=1
gen weight2=1-abs(margin)/0.05


*******************************************************************************
******************************** FIGURE A.3 ***********************************
*******************************************************************************

*** DENSITY OF OBSERVATIONS ***
preserve
keep if abs(margin)<0.05&electable_knr==1
twoway (hist margin if margin<0, bfcolor(gs10) blcolor(gs6) freq width(0.002) start(-0.05) lalign(center)) (hist margin if margin>=0, bfcolor(gs5) blcolor(gs6) freq width(0.002) start(0) lalign(center)), ///
xtitle("Win margin (t)") xlabel(-0.05(0.02)0.05) ytitle("") legend(off) graphregion(color(white)) subtitle("Municipality-level observations")
graph save Fig\gph\density_knr.gph, replace
restore
preserve
keep if abs(margin)<0.05&electable_party_knr==1
twoway (hist margin if margin<0, bfcolor(gs10) blcolor(gs6) freq width(0.002) start(-0.05) lalign(center)) (hist margin if margin>=0, bfcolor(gs5) blcolor(gs6) freq width(0.002) start(0) lalign(center)), ///
xtitle("Win margin (t)") xlabel(-0.05(0.02)0.05) ytitle("") legend(off) graphregion(color(white)) subtitle("Party-municipality-level observations")
graph save Fig\gph\density_partyknr.gph, replace
restore
graph combine Fig\gph\density_knr.gph Fig\gph\density_partyknr.gph, rows(2) ycommon ysize(7) graphregion(color(white))
*graph export ..\figures\density.pdf, replace
graph export Fig\FigA3.pdf, replace


*******************************************************************************
**************** FIGURES 2, 3, 5, A.4, A.5, A.6, A.8, A.9 *********************
*******************************************************************************

gen bins=.
replace bins=1 if margin>-0.050 & margin<-0.045
replace bins=2 if margin>-0.045 & margin<-0.040
replace bins=3 if margin>-0.040 & margin<-0.035
replace bins=4 if margin>-0.035 & margin<-0.030
replace bins=5 if margin>-0.030 & margin<-0.025
replace bins=6 if margin>-0.025 & margin<-0.020
replace bins=7 if margin>-0.020 & margin<-0.015
replace bins=8 if margin>-0.015 & margin<-0.010
replace bins=9 if margin>-0.010 & margin<-0.005
replace bins=10 if margin>-0.005 & margin<-0.000
replace bins=11 if margin>0.000 & margin<0.005
replace bins=12 if margin>0.005 & margin<0.010
replace bins=13 if margin>0.010 & margin<0.015
replace bins=14 if margin>0.015 & margin<0.020
replace bins=15 if margin>0.020 & margin<0.025
replace bins=16 if margin>0.025 & margin<0.030
replace bins=17 if margin>0.030 & margin<0.035
replace bins=18 if margin>0.035 & margin<0.040
replace bins=19 if margin>0.040 & margin<0.045
replace bins=20 if margin>0.045 & margin<0.050
gen midbin=-0.0525+bins*0.005


* Variables for RD plots - party-municpality level outcomes *
foreach var in seat support_diff support_diff_next support_diff_change rank1_knr rank1_knr_next rank2_knr rank2_knr_next rank3_5_knr rank3_5_knr_next mentions mentions_prev mentions_next dmentions dmentions_prev dmentions_next dmentions_rest_share dmentions_rest_share_prev dmentions_rest_share_next  majo Left rank incumbent {

bys bins: egen mean`var'=mean(`var') if abs(margin)<0.05&electable_party_knr==1

*** 95% CI to the left of the cut-off
qui reg `var' margin if margin<0&abs(margin)<0.05&electable_party_knr==1 [pweight=weight1], robust
predict fit`var'
predict fitsd`var', stdp
gen upfit`var'=fit`var'+1.96*fitsd`var' if margin<0
gen downfit`var'=fit`var'-1.96*fitsd`var' if margin<0

*** 95% CI to the right of the cut-off
qui reg `var' margin if margin>0&abs(margin)<0.05&electable_party_knr==1 [pweight=weight1], robust
predict fit_`var'
predict fitsd_`var', stdp
replace upfit`var'=fit_`var'+1.96*fitsd_`var'  if margin>0
replace downfit`var'=fit_`var'-1.96*fitsd_`var'  if margin>0

}

* Variables for RD plots - municpality level outcomes *
foreach var in turnout_diff turnout_diff_next turnout_diff_change road_prev road_curr road_next govempl_prev govempl_curr govempl_next funding_prev funding_curr funding_next Lat Long CountyAdm pop riksveg area seat_knr mentions_anyparty mentions_anyparty_prev mentions_anyparty_next dmentions_anyparty dmentions_anyparty_prev dmentions_anyparty_next {

bys bins: egen mean`var'=mean(`var') if abs(margin)<0.05&electable_knr==1

*** 95% CI to the left of the cut-off
qui reg `var' margin if margin<0&abs(margin)<0.05&electable_knr==1 [pweight=weight1], robust
predict fit`var'
predict fitsd`var', stdp
gen upfit`var'=fit`var'+1.96*fitsd`var' if margin<0
gen downfit`var'=fit`var'-1.96*fitsd`var' if margin<0

*** 95% CI to the right of the cut-off
qui reg `var' margin if margin>0&abs(margin)<0.05&electable_knr==1 [pweight=weight1], robust
predict fit_`var'
predict fitsd_`var', stdp
replace upfit`var'=fit_`var'+1.96*fitsd_`var'  if margin>0
replace downfit`var'=fit_`var'-1.96*fitsd_`var'  if margin>0

}

******************************** FIGURE 2 ************************************* 

cd C:\Users\zruan\Documents\qjps_19147_supp\Fig\gph\ 
 
preserve
keep if abs(margin)<0.05

 foreach var in support_diff {
*** plot
twoway (rarea upfit`var' downfit`var' margin if margin<0, sort fcolor(gs12*0.5) lcolor(gs12*0.5)) (rarea upfit`var' downfit`var' margin if margin>0, sort fcolor(gs12*0.5) lcolor(gs12*0.5)) ///
(line fit`var' margin if margin<0, sort lcolor(black) lwidth(medium)) (line fit_`var' margin if margin>0, sort lcolor(black) lwidth(medium)) (scatter mean`var' midbin, msize(medium) mlwidth(thin) mcolor(black) msymbol(circle_hollow)) , ///
 ytitle("Vote share (hometown vs. rest)") xtitle("Win margin (t)") xline(0, lcolor(black) lwidth(thin)) legend(off)  subtitle("Current election") plotregion(lcolor(white) ilcolor(white)) graphregion(fcolor(white)) scheme(s1mono) ylabel(0(0.01)0.06) xlabel(-0.05(0.02)0.05)
 graph save RDD_`var'.gph, replace
  }
 
  foreach var in support_diff_next {
*** plot
twoway (rarea upfit`var' downfit`var' margin if margin<0, sort fcolor(gs12*0.5) lcolor(gs12*0.5)) (rarea upfit`var' downfit`var' margin if margin>0, sort fcolor(gs12*0.5) lcolor(gs12*0.5)) ///
(line fit`var' margin if margin<0, sort lcolor(black) lwidth(medium)) (line fit_`var' margin if margin>0, sort lcolor(black) lwidth(medium)) (scatter mean`var' midbin, msize(medium) mlwidth(thin) mcolor(black) msymbol(circle_hollow)) , ///
 ytitle("Vote share (hometown vs. rest)") xtitle("Win margin (t)") xline(0, lcolor(black) lwidth(thin)) legend(off)  subtitle("Next election") plotregion(lcolor(white) ilcolor(white)) graphregion(fcolor(white)) scheme(s1mono) ylabel(0(0.01)0.06) xlabel(-0.05(0.02)0.05)
 graph save RDD_`var'.gph, replace
  }
 foreach var in turnout_diff {
*** plot
twoway (rarea upfit`var' downfit`var' margin if margin<0, sort fcolor(gs12*0.5) lcolor(gs12*0.5)) (rarea upfit`var' downfit`var' margin if margin>0, sort fcolor(gs12*0.5) lcolor(gs12*0.5)) ///
(line fit`var' margin if margin<0, sort lcolor(black) lwidth(medium)) (line fit_`var' margin if margin>0, sort lcolor(black) lwidth(medium)) (scatter mean`var' midbin, msize(medium) mlwidth(thin) mcolor(black) msymbol(circle_hollow)) , ///
 ytitle("Turnout (hometown vs. rest)") xtitle("Win margin (t)") xline(0, lcolor(black) lwidth(thin)) legend(off)  subtitle("Current election") plotregion(lcolor(white) ilcolor(white)) graphregion(fcolor(white)) scheme(s1mono) ylabel(-0.02(0.01)0.02) yscale(range(-0.02 0.026)) xlabel(-0.05(0.02)0.05)
 graph save RDD_`var'.gph, replace
  }
 
  foreach var in turnout_diff_next {
*** plot
twoway (rarea upfit`var' downfit`var' margin if margin<0, sort fcolor(gs12*0.5) lcolor(gs12*0.5)) (rarea upfit`var' downfit`var' margin if margin>0, sort fcolor(gs12*0.5) lcolor(gs12*0.5)) ///
(line fit`var' margin if margin<0, sort lcolor(black) lwidth(medium)) (line fit_`var' margin if margin>0, sort lcolor(black) lwidth(medium)) (scatter mean`var' midbin, msize(medium) mlwidth(thin) mcolor(black) msymbol(circle_hollow)) , ///
 ytitle("Turnout (hometown vs. rest)") xtitle("Win margin (t)") xline(0, lcolor(black) lwidth(thin)) legend(off)  subtitle("Next election") plotregion(lcolor(white) ilcolor(white)) graphregion(fcolor(white)) scheme(s1mono) ylabel(-0.02(0.01)0.02) yscale(range(-0.02 0.026)) xlabel(-0.05(0.02)0.05)
 graph save RDD_`var'.gph, replace
  }

  foreach var in support_diff_change {
*** plot
twoway (rarea upfit`var' downfit`var' margin if margin<0, sort fcolor(gs12*0.5) lcolor(gs12*0.5)) (rarea upfit`var' downfit`var' margin if margin>0, sort fcolor(gs12*0.5) lcolor(gs12*0.5)) ///
(line fit`var' margin if margin<0, sort lcolor(black) lwidth(medium)) (line fit_`var' margin if margin>0, sort lcolor(black) lwidth(medium)) (scatter mean`var' midbin, msize(medium) mlwidth(thin) mcolor(black) msymbol(circle_hollow)) , ///
 ytitle("Vote share (hometown vs. rest)") xtitle("Win margin (t)") xline(0, lcolor(black) lwidth(thin)) legend(off)  subtitle("Next vs. current election") plotregion(lcolor(white) ilcolor(white)) graphregion(fcolor(white)) scheme(s1mono) ylabel(-0.03(0.01)0.03) xlabel(-0.05(0.02)0.05)
 graph save RDD_`var'.gph, replace
 }
 foreach var in turnout_diff_change {
*** plot
twoway (rarea upfit`var' downfit`var' margin if margin<0, sort fcolor(gs12*0.5) lcolor(gs12*0.5)) (rarea upfit`var' downfit`var' margin if margin>0, sort fcolor(gs12*0.5) lcolor(gs12*0.5)) ///
(line fit`var' margin if margin<0, sort lcolor(black) lwidth(medium)) (line fit_`var' margin if margin>0, sort lcolor(black) lwidth(medium)) (scatter mean`var' midbin, msize(medium) mlwidth(thin) mcolor(black) msymbol(circle_hollow)) , ///
 ytitle("Turnout (hometown vs. rest)") xtitle("Win margin (t)") xline(0, lcolor(black) lwidth(thin)) legend(off)  subtitle("Next vs. current election") plotregion(lcolor(white) ilcolor(white)) graphregion(fcolor(white)) scheme(s1mono) ylabel(-0.02(0.01)0.02) xlabel(-0.05(0.02)0.05)
 graph save RDD_`var'.gph, replace
 }
  
restore  
  
 * Combined figure with effects on support and turnout *
 graph combine RDD_support_diff.gph RDD_support_diff_next.gph RDD_support_diff_change.gph, rows(1) xsize(7) subtitle("Local party support (relative to rest of district)") graphregion(color(white))
 graph save RDD_support_diff.gph, replace
 graph combine RDD_turnout_diff.gph RDD_turnout_diff_next.gph RDD_turnout_diff_change.gph, ycommon rows(1) xsize(7) subtitle("Local voter turnout (relative to rest of district)") graphregion(color(white))
 graph save RDD_turnout_diff.gph, replace
 graph combine RDD_support_diff.gph RDD_turnout_diff.gph, rows(2) ysize(5) iscale(0.75) graphregion(color(white))
 
cd C:\Users\zruan\Documents\qjps_19147_supp\ 
 
*graph export ..\figures\RDD_support_turnout_diff_sharp.pdf, replace
graph export Fig\Fig2.pdf, replace

  
************************** FIGURE 3 AND FIGURE A.8 **************************** 
 
cd C:\Users\zruan\Documents\qjps_19147_supp\Fig\gph\

preserve
keep if abs(margin)<0.05
 
  foreach var in rank1_knr rank2_knr rank3_5_knr {
*** plot
twoway (rarea upfit`var' downfit`var' margin if margin<0, sort fcolor(gs12*0.5) lcolor(gs12*0.5)) (rarea upfit`var' downfit`var' margin if margin>0, sort fcolor(gs12*0.5) lcolor(gs12*0.5)) ///
(line fit`var' margin if margin<0, sort lcolor(black) lwidth(medium)) (line fit_`var' margin if margin>0, sort lcolor(black) lwidth(medium)) (scatter mean`var' midbin, msize(medium) mlwidth(thin) mcolor(black) msymbol(circle_hollow)) , ///
 ytitle("") xtitle("Win margin (t)") xline(0, lcolor(black) lwidth(thin)) legend(off)  subtitle("Current election") plotregion(lcolor(white) ilcolor(white)) graphregion(fcolor(white)) scheme(s1mono) ylabel(0(0.2)1) xlabel(-0.05(0.02)0.05)
 graph save RDD_`var'_curr.gph, replace
  }
 foreach var in rank1_knr_next rank2_knr_next rank3_5_knr_next {
*** plot
twoway (rarea upfit`var' downfit`var' margin if margin<0, sort fcolor(gs12*0.5) lcolor(gs12*0.5)) (rarea upfit`var' downfit`var' margin if margin>0, sort fcolor(gs12*0.5) lcolor(gs12*0.5)) ///
(line fit`var' margin if margin<0, sort lcolor(black) lwidth(medium)) (line fit_`var' margin if margin>0, sort lcolor(black) lwidth(medium)) (scatter mean`var' midbin, msize(medium) mlwidth(thin) mcolor(black) msymbol(circle_hollow)) , ///
 ytitle("") xtitle("Win margin (t)") xline(0, lcolor(black) lwidth(thin)) legend(off)  subtitle("Next election") plotregion(lcolor(white) ilcolor(white)) graphregion(fcolor(white)) scheme(s1mono) ylabel(0(0.2)1) xlabel(-0.05(0.02)0.05)
 graph save RDD_`var'.gph, replace
 }

restore 
 
 graph combine RDD_rank1_knr_curr.gph RDD_rank1_knr_next.gph, xsize(7) subtitle("Local candidate ranked first") graphregion(color(white))
 graph save RDD_rank1_knr.gph, replace

 graph combine RDD_rank2_knr_curr.gph RDD_rank2_knr_next.gph, xsize(7) subtitle("Local candidate ranked second") graphregion(color(white))
 graph save RDD_rank2_knr.gph, replace
 
cd C:\Users\zruan\Documents\qjps_19147_supp\
 
 graph combine Fig\gph\RDD_rank1_knr.gph Fig\gph\RDD_rank2_knr.gph, rows(2) ysize(6) graphregion(color(white))
 *graph export ..\figures\RDD_rank1_rank2_knr.pdf, replace
 graph export Fig\Fig3.pdf, replace
 
 graph combine Fig\gph\RDD_rank3_5_knr_curr.gph Fig\gph\RDD_rank3_5_knr_next.gph, xsize(7) iscale(*1.2) subtitle("") graphregion(color(white))
 *graph export ..\figures\RDD_rank3_5_knr.pdf, replace
 graph export Fig\FigA8.pdf, replace

 
******************************** FIGURE 5 ************************************* 

cd C:\Users\zruan\Documents\qjps_19147_supp\Fig\gph\  
 
preserve
keep if abs(margin)<0.05
  
local prev "Previous period"
local curr "Current period"
local next "Next period"

foreach period in prev curr next {
twoway (rarea upfitroad_`period' downfitroad_`period' margin if margin<0, sort fcolor(gs12*0.5) lcolor(gs12*0.5)) (rarea upfitroad_`period' downfitroad_`period' margin if margin>0, sort fcolor(gs12*0.5) lcolor(gs12*0.5)) ///
(line fitroad_`period' margin if margin<0, sort lcolor(black) lwidth(medium)) (line fit_road_`period' margin if margin>0, sort lcolor(black) lwidth(medium)) (scatter meanroad_`period' midbin, msize(medium) mlwidth(thin) mcolor(black) msymbol(circle_hollow)) , ///
 ytitle("") xtitle("Win margin (t)") xline(0, lcolor(black) lwidth(thin)) legend(off)  subtitle(``period'') plotregion(lcolor(white) ilcolor(white)) graphregion(fcolor(white)) scheme(s1mono) ylabel(0(0.5)2) xlabel(-0.05(0.02)0.05)
 graph save RDD_road_`period'.gph, replace

twoway (rarea upfitgovempl_`period' downfitgovempl_`period' margin if margin<0, sort fcolor(gs12*0.5) lcolor(gs12*0.5)) (rarea upfitgovempl_`period' downfitgovempl_`period' margin if margin>0, sort fcolor(gs12*0.5) lcolor(gs12*0.5)) ///
(line fitgovempl_`period' margin if margin<0, sort lcolor(black) lwidth(medium)) (line fit_govempl_`period' margin if margin>0, sort lcolor(black) lwidth(medium)) (scatter meangovempl_`period' midbin, msize(medium) mlwidth(thin) mcolor(black) msymbol(circle_hollow)) , ///
 ytitle("") xtitle("Win margin (t)") xline(0, lcolor(black) lwidth(thin)) legend(off)  subtitle(``period'') plotregion(lcolor(white) ilcolor(white)) graphregion(fcolor(white)) scheme(s1mono) ylabel(-1(0.5)1) xlabel(-0.05(0.02)0.05)
 graph save RDD_govempl_`period'.gph, replace
 
 twoway (rarea upfitfunding_`period' downfitfunding_`period' margin if margin<0, sort fcolor(gs12*0.5) lcolor(gs12*0.5)) (rarea upfitfunding_`period' downfitfunding_`period' margin if margin>0, sort fcolor(gs12*0.5) lcolor(gs12*0.5)) ///
(line fitfunding_`period' margin if margin<0, sort lcolor(black) lwidth(medium)) (line fit_funding_`period' margin if margin>0, sort lcolor(black) lwidth(medium)) (scatter meanfunding_`period' midbin, msize(medium) mlwidth(thin) mcolor(black) msymbol(circle_hollow)) , ///
 ytitle("") xtitle("Win margin (t)") xline(0, lcolor(black) lwidth(thin)) legend(off)  subtitle(``period'') plotregion(lcolor(white) ilcolor(white)) graphregion(fcolor(white)) scheme(s1mono) ylabel(0(2000)4000) xlabel(-0.05(0.02)0.05)
 graph save RDD_funding_`period'.gph, replace
 }
 
restore
 
local road "New road constructions (meter/100 inhabitants)"
local govempl "Central government employees (increase/100 inhabitants)" 
local funding "Investment funding from central government (NOK/inhabitants)"

foreach var in road govempl funding {
graph combine RDD_`var'_prev.gph RDD_`var'_curr.gph RDD_`var'_next.gph, rows(1) ycommon subtitle(``var'') graphregion(color(white)) 
graph save RDD_`var'.gph, replace
}
 
graph combine RDD_road.gph RDD_govempl.gph  RDD_funding.gph, rows(3) ysize(6) iscale(0.6) graphregion(color(white)) 

cd C:\Users\zruan\Documents\qjps_19147_supp\

*graph export ..\figures\RDD_policies.pdf, replace
 graph export Fig\Fig5.pdf, replace 
 
 
******************************** FIGURE A.4 ************************************* 

cd C:\Users\zruan\Documents\qjps_19147_supp\Fig\gph\  

preserve
keep if abs(margin)<0.05

twoway (rarea upfitLat downfitLat margin if margin<0, sort fcolor(gs12*0.5) lcolor(gs12*0.5)) (rarea upfitLat downfitLat margin if margin>0, sort fcolor(gs12*0.5) lcolor(gs12*0.5)) ///
(line fitLat margin if margin<0, sort lcolor(black) lwidth(medium)) (line fit_Lat margin if margin>0, sort lcolor(black) lwidth(medium)) (scatter meanLat midbin, msize(medium) mlwidth(thin) mcolor(black) msymbol(circle_hollow)) , ///
 ytitle("") xtitle("Win margin (t)") xline(0, lcolor(black) lwidth(thin)) legend(off)  subtitle("Latitude") plotregion(lcolor(white) ilcolor(white)) graphregion(fcolor(white)) scheme(s1mono) ylabel(60(1)64) xlabel(-0.05(0.02)0.05)
 graph save Balance_Lat.gph, replace

twoway (rarea upfitLong downfitLong margin if margin<0, sort fcolor(gs12*0.5) lcolor(gs12*0.5)) (rarea upfitLong downfitLong margin if margin>0, sort fcolor(gs12*0.5) lcolor(gs12*0.5)) ///
(line fitLong margin if margin<0, sort lcolor(black) lwidth(medium)) (line fit_Long margin if margin>0, sort lcolor(black) lwidth(medium)) (scatter meanLong midbin, msize(medium) mlwidth(thin) mcolor(black) msymbol(circle_hollow)) , ///
 ytitle("") xtitle("Win margin (t)") xline(0, lcolor(black) lwidth(thin)) legend(off)  subtitle("Longitude") plotregion(lcolor(white) ilcolor(white)) graphregion(fcolor(white)) scheme(s1mono) ylabel(8(1)12) xlabel(-0.05(0.02)0.05)
 graph save Balance_Long.gph, replace
 
  twoway (rarea upfitarea downfitarea margin if margin<0, sort fcolor(gs12*0.5) lcolor(gs12*0.5)) (rarea upfitarea downfitarea margin if margin>0, sort fcolor(gs12*0.5) lcolor(gs12*0.5)) ///
(line fitarea margin if margin<0, sort lcolor(black) lwidth(medium)) (line fit_area margin if margin>0, sort lcolor(black) lwidth(medium)) (scatter meanarea midbin, msize(medium) mlwidth(thin) mcolor(black) msymbol(circle_hollow)) , ///
 ytitle("") xtitle("Win margin (t)") xline(0, lcolor(black) lwidth(thin)) legend(off)  subtitle("Area") plotregion(lcolor(white) ilcolor(white)) graphregion(fcolor(white)) scheme(s1mono) ylabel(400(200)1200) xlabel(-0.05(0.02)0.05)
 graph save Balance_area.gph, replace
 
  twoway (rarea upfitpop downfitpop margin if margin<0, sort fcolor(gs12*0.5) lcolor(gs12*0.5)) (rarea upfitpop downfitpop margin if margin>0, sort fcolor(gs12*0.5) lcolor(gs12*0.5)) ///
(line fitpop margin if margin<0, sort lcolor(black) lwidth(medium)) (line fit_pop margin if margin>0, sort lcolor(black) lwidth(medium)) (scatter meanpop midbin, msize(medium) mlwidth(thin) mcolor(black) msymbol(circle_hollow)) , ///
 ytitle("") xtitle("Win margin (t)") xline(0, lcolor(black) lwidth(thin)) legend(off)  subtitle("Population") plotregion(lcolor(white) ilcolor(white)) graphregion(fcolor(white)) scheme(s1mono) ylabel(4000(2000)10000) xlabel(-0.05(0.02)0.05)
 graph save Balance_pop.gph, replace

twoway (rarea upfitCountyAdm downfitCountyAdm margin if margin<0, sort fcolor(gs12*0.5) lcolor(gs12*0.5)) (rarea upfitCountyAdm downfitCountyAdm margin if margin>0, sort fcolor(gs12*0.5) lcolor(gs12*0.5)) ///
(line fitCountyAdm margin if margin<0, sort lcolor(black) lwidth(medium)) (line fit_CountyAdm margin if margin>0, sort lcolor(black) lwidth(medium)) (scatter meanCountyAdm midbin, msize(medium) mlwidth(thin) mcolor(black) msymbol(circle_hollow)) , ///
 ytitle("") xtitle("Win margin (t)") xline(0, lcolor(black) lwidth(thin)) legend(off)  subtitle("Regional capital") plotregion(lcolor(white) ilcolor(white)) graphregion(fcolor(white)) scheme(s1mono) ylabel(0(0.1)0.3) xlabel(-0.05(0.02)0.05)
 graph save Balance_CountyAdm.gph, replace

twoway (rarea upfitriksveg downfitriksveg margin if margin<0, sort fcolor(gs12*0.5) lcolor(gs12*0.5)) (rarea upfitriksveg downfitriksveg margin if margin>0, sort fcolor(gs12*0.5) lcolor(gs12*0.5)) ///
(line fitriksveg margin if margin<0, sort lcolor(black) lwidth(medium)) (line fit_riksveg margin if margin>0, sort lcolor(black) lwidth(medium)) (scatter meanriksveg midbin, msize(medium) mlwidth(thin) mcolor(black) msymbol(circle_hollow)) , ///
 ytitle("") xtitle("Win margin (t)") xline(0, lcolor(black) lwidth(thin)) legend(off)  subtitle("National roads (km)") plotregion(lcolor(white) ilcolor(white)) graphregion(fcolor(white)) scheme(s1mono) ylabel(50(10)90) xlabel(-0.05(0.02)0.05)
 graph save Balance_riksveg.gph, replace

restore 
 
graph combine Balance_Lat.gph Balance_Long.gph Balance_area.gph Balance_pop.gph Balance_CountyAdm.gph Balance_riksveg.gph, rows(3) ysize(7) graphregion(color(white)) 

cd C:\Users\zruan\Documents\qjps_19147_supp\

*graph export ..\figures\Balance.pdf, replace
 graph export Fig\FigA4.pdf, replace 

 
******************************* FIGURE A.5 ************************************  

cd C:\Users\zruan\Documents\qjps_19147_supp\Fig\gph\  

preserve
keep if abs(margin)<0.05

twoway (rarea upfitmajo downfitmajo margin if margin<0, sort fcolor(gs12*0.5) lcolor(gs12*0.5)) (rarea upfitmajo downfitmajo margin if margin>0, sort fcolor(gs12*0.5) lcolor(gs12*0.5)) ///
(line fitmajo margin if margin<0, sort lcolor(black) lwidth(medium)) (line fit_majo margin if margin>0, sort lcolor(black) lwidth(medium)) (scatter meanmajo midbin, msize(medium) mlwidth(thin) mcolor(black) msymbol(circle_hollow)) , ///
 ytitle("") xtitle("Win margin (t)") xline(0, lcolor(black) lwidth(thin)) legend(off)  subtitle("Governing party") plotregion(lcolor(white) ilcolor(white)) graphregion(fcolor(white)) scheme(s1mono) ylabel(0(0.2)1) xlabel(-0.05(0.02)0.05)
 graph save Balance_majo.gph, replace
 
twoway (rarea upfitLeft downfitLeft margin if margin<0, sort fcolor(gs12*0.5) lcolor(gs12*0.5)) (rarea upfitLeft downfitLeft margin if margin>0, sort fcolor(gs12*0.5) lcolor(gs12*0.5)) ///
(line fitLeft margin if margin<0, sort lcolor(black) lwidth(medium)) (line fit_Left margin if margin>0, sort lcolor(black) lwidth(medium)) (scatter meanLeft midbin, msize(medium) mlwidth(thin) mcolor(black) msymbol(circle_hollow)) , ///
 ytitle("") xtitle("Win margin (t)") xline(0, lcolor(black) lwidth(thin)) legend(off)  subtitle("Leftwing party") plotregion(lcolor(white) ilcolor(white)) graphregion(fcolor(white)) scheme(s1mono) ylabel(0(0.2)1) xlabel(-0.05(0.02)0.05)
 graph save Balance_Left.gph, replace
 
twoway (rarea upfitrank downfitrank margin if margin<0, sort fcolor(gs12*0.5) lcolor(gs12*0.5)) (rarea upfitrank downfitrank margin if margin>0, sort fcolor(gs12*0.5) lcolor(gs12*0.5)) ///
(line fitrank margin if margin<0, sort lcolor(black) lwidth(medium)) (line fit_rank margin if margin>0, sort lcolor(black) lwidth(medium)) (scatter meanrank midbin, msize(medium) mlwidth(thin) mcolor(black) msymbol(circle_hollow)) , ///
 ytitle("") xtitle("Win margin (t)") xline(0, lcolor(black) lwidth(thin)) legend(off)  subtitle("Rank") plotregion(lcolor(white) ilcolor(white)) graphregion(fcolor(white)) scheme(s1mono) ylabel(1(1)4) xlabel(-0.05(0.02)0.05)
 graph save Balance_rank.gph, replace 
 
twoway (rarea upfitincumbent downfitincumbent margin if margin<0, sort fcolor(gs12*0.5) lcolor(gs12*0.5)) (rarea upfitincumbent downfitincumbent margin if margin>0, sort fcolor(gs12*0.5) lcolor(gs12*0.5)) ///
(line fitincumbent margin if margin<0, sort lcolor(black) lwidth(medium)) (line fit_incumbent margin if margin>0, sort lcolor(black) lwidth(medium)) (scatter meanincumbent midbin, msize(medium) mlwidth(thin) mcolor(black) msymbol(circle_hollow)) , ///
 ytitle("") xtitle("Win margin (t)") xline(0, lcolor(black) lwidth(thin)) legend(off)  subtitle("Incumbent") plotregion(lcolor(white) ilcolor(white)) graphregion(fcolor(white)) scheme(s1mono) ylabel(0(0.2)1) xlabel(-0.05(0.02)0.05)
 graph save Balance_incumbent.gph, replace 

restore 
 
graph combine Balance_majo.gph Balance_Left.gph Balance_rank.gph Balance_incumbent.gph, rows(2) ysize(5) graphregion(color(white)) 

cd C:\Users\zruan\Documents\qjps_19147_supp\

*graph export ..\figures\BalanceCand.pdf, replace
 graph export Fig\FigA5.pdf, replace  
 
 
******************************* FIGURE A.6 ************************************

 foreach var in seat {
*** plot
twoway (rarea upfit`var' downfit`var' margin if margin<0, sort fcolor(gs12*0.5) lcolor(gs12*0.5)) (rarea upfit`var' downfit`var' margin if margin>0, sort fcolor(gs12*0.5) lcolor(gs12*0.5)) ///
(line fit`var' margin if margin<0, sort lcolor(black) lwidth(medium)) (line fit_`var' margin if margin>0, sort lcolor(black) lwidth(medium)) (scatter mean`var' midbin, msize(medium) mlwidth(thin) mcolor(black) msymbol(circle_hollow)) if abs(margin)<0.05, ///
 ytitle("Seat in parliament") xtitle("Win margin (t)") xline(0, lcolor(black) lwidth(thin)) legend(off)  subtitle("") plotregion(lcolor(white) ilcolor(white)) graphregion(fcolor(white)) scheme(s1mono) ylabel(0(0.2)1) xlabel(-0.05(0.02)0.05)
 *graph export ..\figures\RDD_1ststage.pdf, replace
 }
 graph export Fig\FigA6.pdf, replace

 
******************************* FIGURE A.9 ************************************

cd C:\Users\zruan\Documents\qjps_19147_supp\Fig\gph\

preserve
keep if abs(margin)<0.05

   foreach var in dmentions dmentions_anyparty {
*** plot
twoway (rarea upfit`var' downfit`var' margin if margin<0, sort fcolor(gs12*0.5) lcolor(gs12*0.5)) (rarea upfit`var' downfit`var' margin if margin>0, sort fcolor(gs12*0.5) lcolor(gs12*0.5)) ///
(line fit`var' margin if margin<0, sort lcolor(black) lwidth(medium)) (line fit_`var' margin if margin>0, sort lcolor(black) lwidth(medium)) (scatter mean`var' midbin, msize(medium) mlwidth(thin) mcolor(black) msymbol(circle_hollow)) , ///
 ytitle("") xtitle("Win margin (t)") xline(0, lcolor(black) lwidth(thin)) legend(off)  subtitle("Current period") plotregion(lcolor(white) ilcolor(white)) graphregion(fcolor(white)) scheme(s1mono) yscale(range(0 )) ylabel(#5) xlabel(-0.05(0.02)0.05)
 graph save RDD_`var'.gph, replace
 } 

 foreach var in dmentions_prev dmentions_anyparty_prev {
*** plot
twoway (rarea upfit`var' downfit`var' margin if margin<0, sort fcolor(gs12*0.5) lcolor(gs12*0.5)) (rarea upfit`var' downfit`var' margin if margin>0, sort fcolor(gs12*0.5) lcolor(gs12*0.5)) ///
(line fit`var' margin if margin<0, sort lcolor(black) lwidth(medium)) (line fit_`var' margin if margin>0, sort lcolor(black) lwidth(medium)) (scatter mean`var' midbin, msize(medium) mlwidth(thin) mcolor(black) msymbol(circle_hollow)) , ///
 ytitle("") xtitle("Win margin (t)") xline(0, lcolor(black) lwidth(thin)) legend(off)  subtitle("Previous period") plotregion(lcolor(white) ilcolor(white)) graphregion(fcolor(white)) scheme(s1mono) yscale(range(0 )) ylabel(#5) xlabel(-0.05(0.02)0.05)
 graph save RDD_`var'.gph, replace
 }

 foreach var in dmentions_next dmentions_anyparty_next {
*** plot
twoway (rarea upfit`var' downfit`var' margin if margin<0, sort fcolor(gs12*0.5) lcolor(gs12*0.5)) (rarea upfit`var' downfit`var' margin if margin>0, sort fcolor(gs12*0.5) lcolor(gs12*0.5)) ///
(line fit`var' margin if margin<0, sort lcolor(black) lwidth(medium)) (line fit_`var' margin if margin>0, sort lcolor(black) lwidth(medium)) (scatter mean`var' midbin, msize(medium) mlwidth(thin) mcolor(black) msymbol(circle_hollow)) , ///
 ytitle("") xtitle("Win margin (t)") xline(0, lcolor(black) lwidth(thin)) legend(off)  subtitle("Next period") plotregion(lcolor(white) ilcolor(white)) graphregion(fcolor(white)) scheme(s1mono) yscale(range(0 )) ylabel(#5) xlabel(-0.05(0.02)0.05)
 graph save RDD_`var'.gph, replace
 }
 
restore 
 
  graph combine RDD_dmentions_prev.gph RDD_dmentions.gph RDD_dmentions_next.gph, ycommon rows(1) xsize(7) subtitle("Hometown mentioned by any legislator from the same party") graphregion(color(white))
 graph save RDD_dmentions_3.gph, replace
 graph combine RDD_dmentions_anyparty_prev.gph RDD_dmentions_anyparty.gph RDD_dmentions_anyparty_next.gph, ycommon rows(1) xsize(7) subtitle("Hometown mentioned by any legislator") graphregion(color(white))
 graph save RDD_mentions_anyparty_3.gph, replace
 graph combine RDD_mentions_anyparty_3.gph RDD_dmentions_3.gph, rows(2) ysize(5) iscale(0.75) graphregion(color(white))
 
cd C:\Users\zruan\Documents\qjps_19147_supp\
 
 *graph export ..\figures\RDD_dmentions_paper.pdf, replace
 graph export Fig\FigA9.pdf, replace



******************************************************************************* 
************************ TABLE 2 AND TABLE A.2-A.7 ****************************
*******************************************************************************


********************************* TABLE 2 *************************************  

preserve
* Keep if no other marginal or safe candidates from the same party
keep if abs(margin)<0.05&electable_party_knr==1
  
eststo clear
eststo: qui reg support_diff_change margwin utjevn margin margin_margwin d89 d05 [pweight=weight1], vce(cluster districtid)
qui estadd ysumm
eststo: qui reg support_diff_change seat margin margin_margwin d89 d05 [pweight=weight1], vce(cluster districtid)
qui estadd ysumm
eststo: qui reg support_diff_change seat margin margin_margwin d_year* d89 d05 [pweight=weight1], vce(cluster districtid)
qui estadd ysumm
eststo: qui reg support_diff_change seat margin margin_margwin d_party* d_year* [pweight=weight1], vce(cluster districtid)
qui estadd ysumm
eststo: qui reg support_diff_change seat margin margin_margwin d_party* d_district* d_year* [pweight=weight1], vce(cluster districtid)
qui estadd ysumm
eststo: qui reg support_diff_change seat margin margin_margwin d_party* d_rank* d_district* d_year* [pweight=weight1], vce(cluster districtid)
qui estadd ysumm
eststo: qui reg support_diff_change seat margin margin_margwin d89 d05 [pweight=weight2], vce(cluster districtid)
qui estadd ysumm

esttab using Tab\Tab2.tex, replace style(tex) se b(%9.3f) se(%9.3f) nostar drop(_cons d89 d05 *year* *district* *party* *rank* *margin*) nomtitles label ///
nonotes stats(ymean r2 N, labels("Mean of outcome var." "R-squared" "Observations") fmt(3 2 0)) prehead("\begin{tabular}{l*{@M}{rr}}" "\multicolumn{7}{c}{\textbf{Panel A: Change in local party support (relative to rest of district)}} \\" "\hline") posthead(\hline) postfoot("")
 
keep if electable_knr==1 
eststo clear
eststo: qui reg turnout_diff_change margwin utjevn margin margin_margwin d89 d05 [pweight=weight1], vce(cluster districtid)
qui estadd local YearFE "No"
qui estadd local DistrictFE "No"
qui estadd local PartyFE "No"
qui estadd local RankFE "No"
qui estadd local Kernel "Unif."
qui estadd ysumm
eststo: qui reg turnout_diff_change seat margin margin_margwin d89 d05 [pweight=weight1], vce(cluster districtid)
qui estadd local YearFE "No"
qui estadd local DistrictFE "No"
qui estadd local PartyFE "No"
qui estadd local RankFE "No"
qui estadd local Kernel "Unif."
qui estadd ysumm
eststo: qui reg turnout_diff_change seat margin margin_margwin d_year* d89 d05 [pweight=weight1], vce(cluster districtid)
qui estadd local YearFE "Yes"
qui estadd local DistrictFE "No"
qui estadd local PartyFE "No"
qui estadd local RankFE "No"
qui estadd local Kernel "Unif."
qui estadd ysumm
eststo: qui reg turnout_diff_change seat margin margin_margwin d_party* d_year* [pweight=weight1], vce(cluster districtid)
qui estadd local YearFE "Yes"
qui estadd local DistrictFE "No"
qui estadd local PartyFE "Yes"
qui estadd local RankFE "No"
qui estadd local Kernel "Unif."
qui estadd ysumm
eststo: qui reg turnout_diff_change seat margin margin_margwin d_party* d_district* d_year*  [pweight=weight1], vce(cluster districtid)
qui estadd local YearFE "Yes"
qui estadd local DistrictFE "Yes"
qui estadd local PartyFE "Yes"
qui estadd local RankFE "No"
qui estadd local Kernel "Unif."
qui estadd ysumm
eststo: qui reg turnout_diff_change seat margin margin_margwin d_party* d_year* d_district* d_rank* [pweight=weight1], vce(cluster districtid)
qui estadd local YearFE "Yes"
qui estadd local DistrictFE "Yes"
qui estadd local PartyFE "Yes"
qui estadd local RankFE "Yes"
qui estadd local Kernel "Unif."
qui estadd ysumm
eststo: qui reg turnout_diff_change seat margin margin_margwin d89 d05 [pweight=weight2], vce(cluster districtid)
qui estadd local YearFE "No"
qui estadd local DistrictFE "No"
qui estadd local PartyFE "No"
qui estadd local RankFE "No"
qui estadd local Kernel "Tria."
qui estadd ysumm

esttab using Tab\Tab2.tex, append style(tex) se b(%9.3f) se(%9.3f) nostar drop(_cons d89 d05 *year* *district* *party* *rank* *margin*) nomtitles label ///
nonotes stats(ymean r2 N YearFE PartyFE DistrictFE RankFE Kernel, labels("Mean of outcome var." "R-squared" "Observations" "Time fixed effects" "Party fixed effects" "District fixed effects" "Rank fixed effects") fmt(3 2 0)) prehead("\hline" "\\ \multicolumn{7}{c}{\textbf{Panel B: Change in local voter turnout (relative to rest of district)}} \\" "\hline") posthead(\hline) postfoot("\hline" "\end{tabular}")  
 
restore 

*copy Tab\Tab1.tex ..\tables\support\support_turnout_knr_BW5_FHS2017.tex, replace


******************************** TABLE A.2 ************************************  

preserve
* Keep if no other marginal or safe candidates from the same party
keep if abs(margin)<0.05&electable_party_knr==1
  
eststo clear
eststo: qui reg support_diff_next margwin utjevn margin margin_margwin d89 d05 [pweight=weight1], vce(cluster districtid)
qui estadd ysumm
eststo: qui reg support_diff_next seat margin margin_margwin d89 d05 [pweight=weight1], vce(cluster districtid)
qui estadd ysumm
eststo: qui reg support_diff_next seat margin margin_margwin d_year* d89 d05 [pweight=weight1], vce(cluster districtid)
qui estadd ysumm
eststo: qui reg support_diff_next seat margin margin_margwin d_party* d_year* [pweight=weight1], vce(cluster districtid)
qui estadd ysumm
eststo: qui reg support_diff_next seat margin margin_margwin d_party* d_district* d_year* [pweight=weight1], vce(cluster districtid)
qui estadd ysumm
eststo: qui reg support_diff_next seat margin margin_margwin d_party* d_rank* d_district* d_year* [pweight=weight1], vce(cluster districtid)
qui estadd ysumm
eststo: qui reg support_diff_next seat margin margin_margwin d89 d05 [pweight=weight2], vce(cluster districtid)
qui estadd ysumm

esttab using Tab\TabA2.tex, replace style(tex) se b(%9.3f) se(%9.3f) nostar drop(_cons d89 d05 *year* *district* *party* *rank* *margin*) nomtitles label ///
nonotes stats(ymean r2 N, labels("Mean of outcome var." "R-squared" "Observations") fmt(3 2 0)) prehead("\begin{tabular}{l*{@M}{rr}}" "\multicolumn{7}{c}{\textbf{Panel A: Change in local party support (relative to rest of district)}} \\" "\hline") posthead(\hline) postfoot("")
 
keep if electable_knr==1 
eststo clear
eststo: qui reg turnout_diff_next margwin utjevn margin margin_margwin d89 d05 [pweight=weight1], vce(cluster districtid)
qui estadd local YearFE "No"
qui estadd local DistrictFE "No"
qui estadd local PartyFE "No"
qui estadd local RankFE "No"
qui estadd local Kernel "Unif."
qui estadd ysumm
eststo: qui reg turnout_diff_next seat margin margin_margwin d89 d05 [pweight=weight1], vce(cluster districtid)
qui estadd local YearFE "No"
qui estadd local DistrictFE "No"
qui estadd local PartyFE "No"
qui estadd local RankFE "No"
qui estadd local Kernel "Unif."
qui estadd ysumm
eststo: qui reg turnout_diff_next seat margin margin_margwin d_year* d89 d05 [pweight=weight1], vce(cluster districtid)
qui estadd local YearFE "Yes"
qui estadd local DistrictFE "No"
qui estadd local PartyFE "No"
qui estadd local RankFE "No"
qui estadd local Kernel "Unif."
qui estadd ysumm
eststo: qui reg turnout_diff_next seat margin margin_margwin d_party* d_year* [pweight=weight1], vce(cluster districtid)
qui estadd local YearFE "Yes"
qui estadd local DistrictFE "No"
qui estadd local PartyFE "Yes"
qui estadd local RankFE "No"
qui estadd local Kernel "Unif."
qui estadd ysumm
eststo: qui reg turnout_diff_next seat margin margin_margwin d_party* d_district* d_year*  [pweight=weight1], vce(cluster districtid)
qui estadd local YearFE "Yes"
qui estadd local DistrictFE "Yes"
qui estadd local PartyFE "Yes"
qui estadd local RankFE "No"
qui estadd local Kernel "Unif."
qui estadd ysumm
eststo: qui reg turnout_diff_next seat margin margin_margwin d_party* d_year* d_district* d_rank* [pweight=weight1], vce(cluster districtid)
qui estadd local YearFE "Yes"
qui estadd local DistrictFE "Yes"
qui estadd local PartyFE "Yes"
qui estadd local RankFE "Yes"
qui estadd local Kernel "Unif."
qui estadd ysumm
eststo: qui reg turnout_diff_next seat margin margin_margwin d89 d05 [pweight=weight2], vce(cluster districtid)
qui estadd local YearFE "No"
qui estadd local DistrictFE "No"
qui estadd local PartyFE "No"
qui estadd local RankFE "No"
qui estadd local Kernel "Tria."
qui estadd ysumm

esttab using Tab\TabA2.tex, append style(tex) se b(%9.3f) se(%9.3f) nostar drop(_cons d89 d05 *year* *district* *party* *rank* *margin*) nomtitles label ///
nonotes stats(ymean r2 N YearFE PartyFE DistrictFE RankFE Kernel, labels("Mean of outcome var." "R-squared" "Observations" "Time fixed effects" "Party fixed effects" "District fixed effects" "Rank fixed effects") fmt(3 2 0)) prehead("\hline" "\\ \multicolumn{7}{c}{\textbf{Panel B: Change in local voter turnout (relative to rest of district)}} \\" "\hline") posthead(\hline) postfoot("\hline" "\end{tabular}")  
 
restore 

*copy Tab\TabA2.tex ..\tables\support\support_turnout_knr_BW5_levels.tex, replace


******************************** TABLE A.3 ************************************  
 
preserve
keep if abs(margin)<0.05
 
eststo clear
eststo: qui reg support_diff_change margwin utjevn margin margin_margwin d89 d05 [pweight=weight1], vce(cluster districtid)
qui estadd ysumm
eststo: qui reg support_diff_change seat margin margin_margwin d89 d05 [pweight=weight1], vce(cluster districtid)
qui estadd ysumm
eststo: qui reg support_diff_change seat margin margin_margwin d_year* d89 d05 [pweight=weight1], vce(cluster districtid)
qui estadd ysumm
eststo: qui reg support_diff_change seat margin margin_margwin d_party* d_year* [pweight=weight1], vce(cluster districtid)
qui estadd ysumm
eststo: qui reg support_diff_change seat margin margin_margwin d_party* d_district* d_year* [pweight=weight1], vce(cluster districtid)
qui estadd ysumm
eststo: qui reg support_diff_change seat margin margin_margwin d_party* d_rank* d_district* d_year* [pweight=weight1], vce(cluster districtid)
qui estadd ysumm
eststo: qui reg support_diff_change seat margin margin_margwin d89 d05 [pweight=weight2], vce(cluster districtid)
qui estadd ysumm

esttab using Tab\TabA3.tex, replace style(tex) se b(%9.3f) se(%9.3f) nostar drop(_cons d89 d05 *year* *district* *party* *rank* *margin*) nomtitles label ///
nonotes stats(ymean r2 N, labels("Mean of outcome var." "R-squared" "Observations") fmt(3 2 0)) prehead("\begin{tabular}{l*{@M}{rr}}" "\multicolumn{7}{c}{\textbf{Panel A: Change in local party support (relative to rest of district)}} \\" "\hline") posthead(\hline) postfoot("")
 
eststo clear
eststo: qui reg turnout_diff_change margwin utjevn margin margin_margwin d89 d05 [pweight=weight1], vce(cluster districtid)
qui estadd local YearFE "No"
qui estadd local DistrictFE "No"
qui estadd local PartyFE "No"
qui estadd local RankFE "No"
qui estadd local Kernel "Unif."
qui estadd ysumm
eststo: qui reg turnout_diff_change seat margin margin_margwin d89 d05 [pweight=weight1], vce(cluster districtid)
qui estadd local YearFE "No"
qui estadd local DistrictFE "No"
qui estadd local PartyFE "No"
qui estadd local RankFE "No"
qui estadd local Kernel "Unif."
qui estadd ysumm
eststo: qui reg turnout_diff_change seat margin margin_margwin d_year* d89 d05 [pweight=weight1], vce(cluster districtid)
qui estadd local YearFE "Yes"
qui estadd local DistrictFE "No"
qui estadd local PartyFE "No"
qui estadd local RankFE "No"
qui estadd local Kernel "Unif."
qui estadd ysumm
eststo: qui reg turnout_diff_change seat margin margin_margwin d_party* d_year* [pweight=weight1], vce(cluster districtid)
qui estadd local YearFE "Yes"
qui estadd local DistrictFE "No"
qui estadd local PartyFE "Yes"
qui estadd local RankFE "No"
qui estadd local Kernel "Unif."
qui estadd ysumm
eststo: qui reg turnout_diff_change seat margin margin_margwin d_party* d_district* d_year*  [pweight=weight1], vce(cluster districtid)
qui estadd local YearFE "Yes"
qui estadd local DistrictFE "Yes"
qui estadd local PartyFE "Yes"
qui estadd local RankFE "No"
qui estadd local Kernel "Unif."
qui estadd ysumm
eststo: qui reg turnout_diff_change seat margin margin_margwin d_party* d_year* d_district* d_rank* [pweight=weight1], vce(cluster districtid)
qui estadd local YearFE "Yes"
qui estadd local DistrictFE "Yes"
qui estadd local PartyFE "Yes"
qui estadd local RankFE "Yes"
qui estadd local Kernel "Unif."
qui estadd ysumm
eststo: qui reg turnout_diff_change seat margin margin_margwin d89 d05 [pweight=weight2], vce(cluster districtid)
qui estadd local YearFE "No"
qui estadd local DistrictFE "No"
qui estadd local PartyFE "No"
qui estadd local RankFE "No"
qui estadd local Kernel "Tria."
qui estadd ysumm

esttab using Tab\TabA3.tex, append style(tex) se b(%9.3f) se(%9.3f) nostar drop(_cons d89 d05 *year* *district* *party* *rank* *margin*) nomtitles label ///
nonotes stats(ymean r2 N YearFE PartyFE DistrictFE RankFE Kernel, labels("Mean of outcome var." "R-squared" "Observations" "Time fixed effects" "Party fixed effects" "District fixed effects" "Rank fixed effects") fmt(3 2 0)) prehead("\hline" "\\ \multicolumn{7}{c}{\textbf{Panel B: Change in local voter turnout (relative to rest of district)}} \\" "\hline") posthead(\hline) postfoot("\hline" "\end{tabular}")  
 
restore

*copy Tab\TabA3.tex ..\tables\support\support_turnout_knr_BW5_fullsample.tex, replace 


******************************** TABLE A.4 ************************************  

preserve
* Keep if no other marginal or safe candidates from the same party
keep if abs(margin)<0.05&electable_party_knr==1&year>=1965
  
eststo clear
eststo: qui reg support_diff_change margwin utjevn margin margin_margwin d89 d05 [pweight=weight1], vce(cluster districtid)
qui estadd ysumm
eststo: qui reg support_diff_change seat margin margin_margwin d89 d05 [pweight=weight1], vce(cluster districtid)
qui estadd ysumm
eststo: qui reg support_diff_change seat margin margin_margwin d_year* d89 d05 [pweight=weight1], vce(cluster districtid)
qui estadd ysumm
eststo: qui reg support_diff_change seat margin margin_margwin d_party* d_year* [pweight=weight1], vce(cluster districtid)
qui estadd ysumm
eststo: qui reg support_diff_change seat margin margin_margwin d_party* d_district* d_year* [pweight=weight1], vce(cluster districtid)
qui estadd ysumm
eststo: qui reg support_diff_change seat margin margin_margwin d_party* d_rank* d_district* d_year* [pweight=weight1], vce(cluster districtid)
qui estadd ysumm
eststo: qui reg support_diff_change seat margin margin_margwin d89 d05 [pweight=weight2], vce(cluster districtid)
qui estadd ysumm

esttab using Tab\TabA4.tex, replace style(tex) se b(%9.3f) se(%9.3f) nostar drop(_cons d89 d05 *year* *district* *party* *rank* *margin*) nomtitles label ///
nonotes stats(ymean r2 N, labels("Mean of outcome var." "R-squared" "Observations") fmt(3 2 0)) prehead("\begin{tabular}{l*{@M}{rr}}" "\multicolumn{7}{c}{\textbf{Panel A: Change in local party support (relative to rest of district)}} \\" "\hline") posthead(\hline) postfoot("")
 
keep if electable_knr==1 
eststo clear
eststo: qui reg turnout_diff_change margwin utjevn margin margin_margwin d89 d05 [pweight=weight1], vce(cluster districtid)
qui estadd local YearFE "No"
qui estadd local DistrictFE "No"
qui estadd local PartyFE "No"
qui estadd local RankFE "No"
qui estadd local Kernel "Unif."
qui estadd ysumm
eststo: qui reg turnout_diff_change seat margin margin_margwin d89 d05 [pweight=weight1], vce(cluster districtid)
qui estadd local YearFE "No"
qui estadd local DistrictFE "No"
qui estadd local PartyFE "No"
qui estadd local RankFE "No"
qui estadd local Kernel "Unif."
qui estadd ysumm
eststo: qui reg turnout_diff_change seat margin margin_margwin d_year* d89 d05 [pweight=weight1], vce(cluster districtid)
qui estadd local YearFE "Yes"
qui estadd local DistrictFE "No"
qui estadd local PartyFE "No"
qui estadd local RankFE "No"
qui estadd local Kernel "Unif."
qui estadd ysumm
eststo: qui reg turnout_diff_change seat margin margin_margwin d_party* d_year* [pweight=weight1], vce(cluster districtid)
qui estadd local YearFE "Yes"
qui estadd local DistrictFE "No"
qui estadd local PartyFE "Yes"
qui estadd local RankFE "No"
qui estadd local Kernel "Unif."
qui estadd ysumm
eststo: qui reg turnout_diff_change seat margin margin_margwin d_party* d_district* d_year*  [pweight=weight1], vce(cluster districtid)
qui estadd local YearFE "Yes"
qui estadd local DistrictFE "Yes"
qui estadd local PartyFE "Yes"
qui estadd local RankFE "No"
qui estadd local Kernel "Unif."
qui estadd ysumm
eststo: qui reg turnout_diff_change seat margin margin_margwin d_party* d_year* d_district* d_rank* [pweight=weight1], vce(cluster districtid)
qui estadd local YearFE "Yes"
qui estadd local DistrictFE "Yes"
qui estadd local PartyFE "Yes"
qui estadd local RankFE "Yes"
qui estadd local Kernel "Unif."
qui estadd ysumm
eststo: qui reg turnout_diff_change seat margin margin_margwin d89 d05 [pweight=weight2], vce(cluster districtid)
qui estadd local YearFE "No"
qui estadd local DistrictFE "No"
qui estadd local PartyFE "No"
qui estadd local RankFE "No"
qui estadd local Kernel "Tria."
qui estadd ysumm

esttab using Tab\TabA4.tex, append style(tex) se b(%9.3f) se(%9.3f) nostar drop(_cons d89 d05 *year* *district* *party* *rank* *margin*) nomtitles label ///
nonotes stats(ymean r2 N YearFE PartyFE DistrictFE RankFE Kernel, labels("Mean of outcome var." "R-squared" "Observations" "Time fixed effects" "Party fixed effects" "District fixed effects" "Rank fixed effects") fmt(3 2 0)) prehead("\hline" "\\ \multicolumn{7}{c}{\textbf{Panel B: Change in local voter turnout (relative to rest of district)}} \\" "\hline") posthead(\hline) postfoot("\hline" "\end{tabular}")  
 
restore 

*copy Tab\TabA4.tex ..\tables\support\support_turnout_knr_BW5_post1964.tex, replace


******************************** TABLE A.5 ************************************  

preserve
* Keep if no other marginal or safe candidates from the same party
keep if abs(margin)<0.05&electable_party_knr==1

eststo clear
eststo: qui reg rank1_knr_next margwin utjevn margin margin_margwin d89 d05 [pweight=weight1], vce(cluster districtid)
qui estadd local YearFE "No"
qui estadd local DistrictFE "No"
qui estadd local PartyFE "No"
qui estadd local RankFE "No"
qui estadd local Kernel "Unif."
qui estadd ysumm
eststo: qui reg rank1_knr_next seat margin margin_margwin d89 d05 [pweight=weight1], vce(cluster districtid)
qui estadd local YearFE "No"
qui estadd local DistrictFE "No"
qui estadd local PartyFE "No"
qui estadd local RankFE "No"
qui estadd local Kernel "Unif."
qui estadd ysumm
eststo: qui reg rank1_knr_next seat margin margin_margwin d_year* d89 d05 [pweight=weight1], vce(cluster districtid)
qui estadd local YearFE "Yes"
qui estadd local DistrictFE "No"
qui estadd local PartyFE "No"
qui estadd local RankFE "No"
qui estadd local Kernel "Unif."
qui estadd ysumm
eststo: qui reg rank1_knr_next seat margin margin_margwin d_party* d_year* [pweight=weight1], vce(cluster districtid)
qui estadd local YearFE "Yes"
qui estadd local DistrictFE "No"
qui estadd local PartyFE "Yes"
qui estadd local RankFE "No"
qui estadd local Kernel "Unif."
qui estadd ysumm
eststo: qui reg rank1_knr_next seat margin margin_margwin d_party* d_district* d_year*  [pweight=weight1], vce(cluster districtid)
qui estadd local YearFE "Yes"
qui estadd local DistrictFE "Yes"
qui estadd local PartyFE "Yes"
qui estadd local RankFE "No"
qui estadd local Kernel "Unif."
qui estadd ysumm
eststo: qui reg rank1_knr_next seat margin margin_margwin d_party* d_year* d_district* d_rank* [pweight=weight1], vce(cluster districtid)
qui estadd local YearFE "Yes"
qui estadd local DistrictFE "Yes"
qui estadd local PartyFE "Yes"
qui estadd local RankFE "Yes"
qui estadd local Kernel "Unif."
qui estadd ysumm
eststo: qui reg rank1_knr_next seat margin margin_margwin d89 d05 [pweight=weight2], vce(cluster districtid)
qui estadd local YearFE "No"
qui estadd local DistrictFE "No"
qui estadd local PartyFE "No"
qui estadd local RankFE "No"
qui estadd local Kernel "Tria."
qui estadd ysumm

esttab using Tab\TabA5.tex, replace style(tex) se b(%9.3f) se(%9.3f) nostar drop(_cons d89 d05 *year* *district* *party* *rank* *margin*) nomtitles label ///
nonotes stats(ymean r2 N YearFE PartyFE DistrictFE RankFE Kernel, labels("Mean of outcome var." "R-squared" "Observations" "Time fixed effects" "Party fixed effects" "District fixed effects" "Rank fixed effects") fmt(3 2 0)) /// 
prehead("\begin{tabular}{l*{@M}{rr}}" "\hline") posthead(\hline) postfoot("\hline" "\end{tabular}")  
restore

*copy Tab\TabA5.tex ..\tables\support\drank1_knr_BW5_FHS2017.tex, replace


******************************** TABLE A.6 ************************************  

preserve
* Keep if no other marginal or safe candidates from any party
keep if abs(margin)<0.05&electable_knr==1

eststo clear
eststo: qui reg dmentions_anyparty margwin utjevn margin margin_margwin d89 d05 [pweight=weight1], vce(cluster districtid)
qui estadd ysumm
eststo: qui reg dmentions_anyparty seat margin margin_margwin d89 d05 [pweight=weight1], vce(cluster districtid)
qui estadd ysumm
eststo: qui reg dmentions_anyparty seat margin margin_margwin d_year* d89 d05 [pweight=weight1], vce(cluster districtid)
qui estadd ysumm
eststo: qui reg dmentions_anyparty seat margin margin_margwin d_party* d_year* [pweight=weight1], vce(cluster districtid)
qui estadd ysumm
eststo: qui reg dmentions_anyparty seat margin margin_margwin d_party* d_district* d_year* [pweight=weight1], vce(cluster districtid)
qui estadd ysumm
eststo: qui reg dmentions_anyparty seat margin margin_margwin d_party* d_rank* d_district* d_year* [pweight=weight1], vce(cluster districtid)
qui estadd ysumm
eststo: qui reg dmentions_anyparty seat margin margin_margwin d89 d05 [pweight=weight2], vce(cluster districtid)
qui estadd ysumm

esttab using Tab\TabA6.tex, replace style(tex) se b(%9.3f) se(%9.3f) nostar drop(_cons d89 d05 *year* *district* *party* *rank* *margin*) nomtitles label ///
nonotes stats(ymean r2 N, labels("Mean of outcome var." "R-squared" "Observations") fmt(3 2 0)) prehead("\begin{tabular}{l*{@M}{rr}}" "\multicolumn{8}{c}{\textbf{Panel A: Hometown mentioned by any legislator}} \\" "\hline") posthead(\hline) postfoot("")
restore

preserve
* Keep if no other marginal or safe candidates from the same party
keep if abs(margin)<0.05&electable_party_knr==1 
 
eststo clear
eststo: qui reg dmentions margwin utjevn margin margin_margwin d89 d05 [pweight=weight1], vce(cluster districtid)
qui estadd local YearFE "No"
qui estadd local DistrictFE "No"
qui estadd local PartyFE "No"
qui estadd local RankFE "No"
qui estadd local Kernel "Unif."
qui estadd ysumm
eststo: qui reg dmentions seat margin margin_margwin d89 d05 [pweight=weight1], vce(cluster districtid)
qui estadd local YearFE "No"
qui estadd local DistrictFE "No"
qui estadd local PartyFE "No"
qui estadd local RankFE "No"
qui estadd local Kernel "Unif."
qui estadd ysumm
eststo: qui reg dmentions seat margin margin_margwin d_year* d89 d05 [pweight=weight1], vce(cluster districtid)
qui estadd local YearFE "Yes"
qui estadd local DistrictFE "No"
qui estadd local PartyFE "No"
qui estadd local RankFE "No"
qui estadd local Kernel "Unif."
qui estadd ysumm
eststo: qui reg dmentions seat margin margin_margwin d_party* d_year* [pweight=weight1], vce(cluster districtid)
qui estadd local YearFE "Yes"
qui estadd local DistrictFE "No"
qui estadd local PartyFE "Yes"
qui estadd local RankFE "No"
qui estadd local Kernel "Unif."
qui estadd ysumm
eststo: qui reg dmentions seat margin margin_margwin d_party* d_district* d_year*  [pweight=weight1], vce(cluster districtid)
qui estadd local YearFE "Yes"
qui estadd local DistrictFE "Yes"
qui estadd local PartyFE "Yes"
qui estadd local RankFE "No"
qui estadd local Kernel "Unif."
qui estadd ysumm
eststo: qui reg dmentions seat margin margin_margwin d_party* d_year* d_district* d_rank* [pweight=weight1], vce(cluster districtid)
qui estadd local YearFE "Yes"
qui estadd local DistrictFE "Yes"
qui estadd local PartyFE "Yes"
qui estadd local RankFE "Yes"
qui estadd local Kernel "Unif."
qui estadd ysumm
eststo: qui reg dmentions seat margin margin_margwin d89 d05 [pweight=weight2], vce(cluster districtid)
qui estadd local YearFE "No"
qui estadd local DistrictFE "No"
qui estadd local PartyFE "No"
qui estadd local RankFE "No"
qui estadd local Kernel "Tria."
qui estadd ysumm
restore

esttab using Tab\TabA6.tex, append style(tex) se b(%9.3f) se(%9.3f) nostar drop(_cons d89 d05 *year* *district* *party* *rank* *margin*) nomtitles label ///
nonotes stats(ymean r2 N YearFE PartyFE DistrictFE RankFE Kernel, labels("Mean of outcome var." "R-squared" "Observations" "Time fixed effects" "Party fixed effects" "District fixed effects" "Rank fixed effects") fmt(3 2 0)) prehead("\hline" "\\ \multicolumn{8}{c}{\textbf{Panel B: Hometown mentioned by any legislator from the same party}} \\" "\hline") posthead(\hline) postfoot("\hline" "\end{tabular}")  

*copy Tab\TabA6.tex ..\tables\dmentions_hometown_BW5_FHS2017.tex, replace


******************************** TABLE A.7 ************************************  

preserve
keep if abs(margin)<0.05&electable_knr==1

eststo clear
foreach var in road_prev road_curr road_next {
eststo: qui reg `var' seat margin margin_margwin d89 d05 [pweight=weight1], vce(cluster districtid)
qui estadd ysumm
eststo: qui reg `var' seat margin margin_margwin d_party* d_rank* d_district* d_year* [pweight=weight2], vce(cluster districtid)
qui estadd ysumm
}

esttab using Tab\TabA7.tex, replace style(tex) se b(%9.3f) se(%9.3f) nostar /// 
drop(_cons d89 d05 *year* *district* *party* *rank* *margin*) mtitles("Prev." "Prev." "Curr." "Curr." "Next" "Next") label ///
nonotes stats(ymean r2 N, labels("Mean of outcome var." "R-squared" "Observations") fmt(3 2 0)) ///
prehead("\begin{tabular}{l*{@M}{rr}}" "\multicolumn{7}{c}{\textbf{Panel A: New road constructions (meter/100 inhabitants)}} \\" "\hline") posthead(\hline) postfoot("")

eststo clear
foreach var in govempl_prev govempl_curr govempl_next {
eststo: qui reg `var' seat margin margin_margwin d89 d05 [pweight=weight1], vce(cluster districtid)
qui estadd ysumm
eststo: qui reg `var' seat margin margin_margwin d_party* d_rank* d_district* d_year* [pweight=weight2], vce(cluster districtid)
qui estadd ysumm
}

esttab using Tab\TabA7.tex, append style(tex) se b(%9.3f) se(%9.3f) nostar /// 
drop(_cons d89 d05 *year* *district* *party* *rank* *margin*) mtitles("Prev." "Prev." "Curr." "Curr." "Next" "Next") label ///
nonotes stats(ymean r2 N, labels("Mean of outcome var." "R-squared" "Observations") fmt(3 2 0)) ///
prehead("\hline" "\\ \multicolumn{7}{c}{\textbf{Panel B: Central government jobs (increase 100/inhabitants)}} \\" "\hline") posthead(\hline) postfoot("")

eststo clear
foreach var in funding_prev funding_curr funding_next {
eststo: qui reg `var' seat margin margin_margwin d89 d05 [pweight=weight1], vce(cluster districtid)
qui estadd local YearFE "No"
qui estadd local DistrictFE "No"
qui estadd local PartyFE "No"
qui estadd local RankFE "No"
qui estadd local Kernel "Unif."
qui estadd ysumm
eststo: qui reg `var' seat margin margin_margwin d_party* d_rank* d_district* d_year* [pweight=weight2], vce(cluster districtid)
qui estadd local YearFE "Yes"
qui estadd local DistrictFE "Yes"
qui estadd local PartyFE "Yes"
qui estadd local RankFE "Yes"
qui estadd local Kernel "Tria."
qui estadd ysumm
}

esttab using Tab\TabA7.tex, append style(tex) se b(%9.3f) se(%9.3f) nostar /// 
drop(_cons d89 d05 *year* *district* *party* *rank* *margin*) mtitles("Prev." "Prev." "Curr." "Curr." "Next" "Next") label ///
nonotes stats(ymean r2 N YearFE PartyFE DistrictFE RankFE Kernel, labels("Mean of outcome var." "R-squared" "Observations") fmt(3 2 0)) ///
prehead("\hline" "\\ \multicolumn{7}{c}{\textbf{Panel C: Investment funding (NOK 2015/inhabitant)}} \\" "\hline") posthead(\hline) postfoot("\hline" "\end{tabular}")  

restore

*copy Tab\TabA7.tex ..\tables\policies_knr_BW5_FHS2017.tex, replace


******************************** TABLE A.8 ************************************  

preserve
keep if abs(margin)<0.05&electable_party_knr==1&majo==1
eststo clear
eststo: qui reg support_diff_change margwin utjevn margin margin_margwin d89 d05 [pweight=weight1], vce(cluster districtid)
qui estadd ysumm
eststo: qui reg support_diff_change seat margin margin_margwin d89 d05 [pweight=weight1], vce(cluster districtid)
qui estadd ysumm
eststo: qui reg support_diff_change seat margin margin_margwin d_year* d89 d05 [pweight=weight1], vce(cluster districtid)
qui estadd ysumm
eststo: qui reg support_diff_change seat margin margin_margwin d_party* d_year* [pweight=weight1], vce(cluster districtid)
qui estadd ysumm
eststo: qui reg support_diff_change seat margin margin_margwin d_party* d_district* d_year* [pweight=weight1], vce(cluster districtid)
qui estadd ysumm
eststo: qui reg support_diff_change seat margin margin_margwin d_party* d_rank* d_district* d_year* [pweight=weight1], vce(cluster districtid)
qui estadd ysumm
eststo: qui reg support_diff_change seat margin margin_margwin d89 d05 [pweight=weight2], vce(cluster districtid)
qui estadd ysumm

esttab using Tab\TabA8.tex, replace style(tex) se b(%9.3f) se(%9.3f) nostar drop(_cons d89 d05 *year* *district* *party* *rank* *margin*) nomtitles label ///
nonotes stats(ymean r2 N, labels("Mean of outcome var." "R-squared" "Observations") fmt(3 2 0)) prehead("\begin{tabular}{l*{@M}{rr}}" "\multicolumn{7}{c}{\textbf{Panel A: Candidates from party/parties in government}} \\" "\hline") posthead(\hline) postfoot("")
restore 
 
preserve
keep if abs(margin)<0.05&electable_party_knr==1&majo==0
eststo clear
eststo: qui reg support_diff_change margwin utjevn margin margin_margwin d89 d05 [pweight=weight1], vce(cluster districtid)
qui estadd local YearFE "No"
qui estadd local DistrictFE "No"
qui estadd local PartyFE "No"
qui estadd local RankFE "No"
qui estadd local Kernel "Unif."
qui estadd ysumm
eststo: qui reg support_diff_change seat margin margin_margwin d89 d05 [pweight=weight1], vce(cluster districtid)
qui estadd local YearFE "No"
qui estadd local DistrictFE "No"
qui estadd local PartyFE "No"
qui estadd local RankFE "No"
qui estadd local Kernel "Unif."
qui estadd ysumm
eststo: qui reg support_diff_change seat margin margin_margwin d_year* d89 d05 [pweight=weight1], vce(cluster districtid)
qui estadd local YearFE "Yes"
qui estadd local DistrictFE "No"
qui estadd local PartyFE "No"
qui estadd local RankFE "No"
qui estadd local Kernel "Unif."
qui estadd ysumm
eststo: qui reg support_diff_change seat margin margin_margwin d_party* d_year* [pweight=weight1], vce(cluster districtid)
qui estadd local YearFE "Yes"
qui estadd local DistrictFE "No"
qui estadd local PartyFE "Yes"
qui estadd local RankFE "No"
qui estadd local Kernel "Unif."
qui estadd ysumm
eststo: qui reg support_diff_change seat margin margin_margwin d_party* d_district* d_year*  [pweight=weight1], vce(cluster districtid)
qui estadd local YearFE "Yes"
qui estadd local DistrictFE "Yes"
qui estadd local PartyFE "Yes"
qui estadd local RankFE "No"
qui estadd local Kernel "Unif."
qui estadd ysumm
eststo: qui reg support_diff_change seat margin margin_margwin d_party* d_year* d_district* d_rank* [pweight=weight1], vce(cluster districtid)
qui estadd local YearFE "Yes"
qui estadd local DistrictFE "Yes"
qui estadd local PartyFE "Yes"
qui estadd local RankFE "Yes"
qui estadd local Kernel "Unif."
qui estadd ysumm
eststo: qui reg support_diff_change seat margin margin_margwin d89 d05 [pweight=weight2], vce(cluster districtid)
qui estadd local YearFE "No"
qui estadd local DistrictFE "No"
qui estadd local PartyFE "No"
qui estadd local RankFE "No"
qui estadd local Kernel "Tria."
qui estadd ysumm

esttab using Tab\TabA8.tex, append style(tex) se b(%9.3f) se(%9.3f) nostar drop(_cons d89 d05 *year* *district* *party* *rank* *margin*) nomtitles label ///
nonotes stats(ymean r2 N YearFE PartyFE DistrictFE RankFE Kernel, labels("Mean of outcome var." "R-squared" "Observations" "Time fixed effects" "Party fixed effects" "District fixed effects" "Rank fixed effects") fmt(3 2 0)) prehead("\hline" "\\ \multicolumn{7}{c}{\textbf{Panel B: Candidates from parties not in government}} \\" "\hline") posthead(\hline) postfoot("\hline" "\end{tabular}") 
 
restore 

*copy Tab\TabA8.tex ..\tables\support\support_knr_BW5_splitalign_FHS2017.tex, replace


 
*******************************************************************************
****************************** FIGURE A.7 *************************************
*******************************************************************************

postfile dataset str20(depvar) poly str10(FE) str10(kernel) BW beta lower upper obs clusters using Fig\estimates.dta, replace

drop electable*

foreach depvar in support_diff_change dmentions rank1_knr_next {
forval BW=0.0025(0.0025)0.15 {
preserve
replace weight2=1-abs(margin)/`BW'
* Number of electable candidates (marginal or safe) *
egen electable_party_knr=total(margin>-`BW'|margin==.&seat==1), by(hometownID party year)
keep if abs(margin)<`BW'&electable_party_knr==1
gen weight=1-abs(margin)/`BW'
qui reg `depvar' seat margin margin_margwin d89 d05 [pweight=weight1], vce(cluster districtid)
post dataset ("`depvar'") (1) ("none") ("Unif.") (`BW') (_b[seat]) (_b[seat]-_se[seat]*2.160) (_b[seat]+_se[seat]*2.160) (e(N)) (e(N_clust))
qui reg `depvar' seat margin margin_margwin d89 d05 [pweight=weight2], vce(cluster districtid)
post dataset ("`depvar'") (1) ("none") ("Tria.") (`BW') (_b[seat]) (_b[seat]-_se[seat]*2.160) (_b[seat]+_se[seat]*2.160) (e(N)) (e(N_clust))
restore
}
}
foreach depvar in turnout_diff_change road_curr govempl_curr funding_curr {
forval BW=0.0025(0.0025)0.15 {
preserve
replace weight2=1-abs(margin)/`BW'
* Number of electable candidates (marginal or safe) *
egen electable_knr=total(margin>-`BW'&margin!=.|margin==.&seat==1), by(hometownID year)
keep if abs(margin)<`BW'&electable_knr==1
gen weight=1
qui reg `depvar' seat margin margin_margwin d89 d05 [pweight=weight1], vce(cluster districtid)
post dataset ("`depvar'") (1) ("none") ("Unif.") (`BW') (_b[seat]) (_b[seat]-_se[seat]*2.160) (_b[seat]+_se[seat]*2.160) (e(N)) (e(N_clust))
qui reg `depvar' seat margin margin_margwin d89 d05 [pweight=weight2], vce(cluster districtid)
post dataset ("`depvar'") (1) ("none") ("Tria.") (`BW') (_b[seat]) (_b[seat]-_se[seat]*2.160) (_b[seat]+_se[seat]*2.160) (e(N)) (e(N_clust))
restore
}
}

postclose dataset

preserve
use Fig\estimates, clear

cd C:\Users\zruan\Documents\qjps_19147_supp\Fig\gph\

twoway (line lower BW, lcolor(gray) lpattern(dash)) (line beta BW, lcolor(black)) (line upper BW, lcolor(gray) lpattern(dash)) if depvar=="road_curr"&poly==1&FE=="none"&kernel=="Unif."&BW>=0.005&BW<=0.101, ///
xtitle("Bandwidth") legend(off) ylabel(-1(1)1) yscale(range()) graphregion(color(white)) subtitle("Road constructions")
graph save bandwidths_road_curr.gph, replace

twoway (line lower BW, lcolor(gray) lpattern(dash)) (line beta BW, lcolor(black)) (line upper BW, lcolor(gray) lpattern(dash)) if depvar=="govempl_curr"&poly==1&FE=="none"&kernel=="Unif."&BW>=0.005&BW<=0.101, ///
xtitle("Bandwidth") legend(off) ylabel(-0.5(0.5)0.5) yscale(range()) graphregion(color(white)) subtitle("Government employees")
graph save bandwidths_govempl_curr.gph, replace

twoway (line lower BW, lcolor(gray) lpattern(dash)) (line beta BW, lcolor(black)) (line upper BW, lcolor(gray) lpattern(dash)) if depvar=="funding_curr"&poly==1&FE=="none"&kernel=="Unif."&BW>=0.005&BW<=0.101, ///
xtitle("Bandwidth") legend(off) ylabel(-3000(3000)3000) yscale(range()) graphregion(color(white)) subtitle("Investment funding")
graph save bandwidths_funding_curr.gph, replace

twoway (line lower BW, lcolor(gray) lpattern(dash)) (line beta BW, lcolor(black)) (line upper BW, lcolor(gray) lpattern(dash)) if depvar=="support_diff_change"&poly==1&FE=="none"&kernel=="Unif."&BW>=0.005&BW<=0.101, ///
xtitle("Bandwidth") legend(off) ylabel(-0.02(0.02)0.02) yscale(range()) graphregion(color(white)) subtitle("Local party support")
graph save bandwidths_support_diff_change.gph, replace

twoway (line lower BW, lcolor(gray) lpattern(dash)) (line beta BW, lcolor(black)) (line upper BW, lcolor(gray) lpattern(dash)) if depvar=="turnout_diff_change"&poly==1&FE=="none"&kernel=="Unif."&BW>=0.005&BW<=0.101, ///
xtitle("Bandwidth") legend(off) ylabel(-0.02(0.02)0.02) yscale(range()) graphregion(color(white)) subtitle("Local voter turnout")
graph save bandwidths_turnout_diff_change.gph, replace

twoway (line lower BW, lcolor(gray) lpattern(dash)) (line beta BW, lcolor(black)) (line upper BW, lcolor(gray) lpattern(dash)) if depvar=="rank1_knr_next"&poly==1&FE=="none"&kernel=="Unif."&BW>=0.005&BW<=0.101, ///
xtitle("Bandwidth") legend(off) ylabel(-0.5(0.5)0.5) yscale(range()) graphregion(color(white)) subtitle("Local top candidate at t+4")
graph save bandwidths_rank1_knr_next.gph, replace

restore

graph combine bandwidths_support_diff_change.gph bandwidths_turnout_diff_change.gph bandwidths_rank1_knr_next.gph bandwidths_road_curr.gph bandwidths_govempl_curr.gph bandwidths_funding_curr.gph ///
, rows(3) graphregion(color(white)) ysize(6) iscale(0.6)

cd C:\Users\zruan\Documents\qjps_19147_supp\

*graph export ..\figures\bandwidths.pdf, replace
graph export Fig\FigA7.pdf, replace

