*cd c:\users\ash\dropbox\riksveg\replication
*cd C:\Users\A0910846\Dropbox\FivaHalseSmith\replication

use dta\hometowndata, clear

* Drop Oslo and Bergen districts, and Vestfold 2013 (many missing hometowns) * 
drop if districtid==3|districtid==13|districtid==7&year==2013

*******************************************************************************
******************************** TABLE A1 *************************************
*******************************************************************************

replace pop=pop/1000
replace cgfund_inv=cgfund_inv/1000

lab var meterCAP_curr "New road constructions (meter/100 inhabitants)"
lab var d_govempl "Central gov. employees (increase/100 inhab.)"
lab var cgfund_inv "Inv. funding from central gov. (1000 NOK/inhab.)"
lab var Latitude "Latitude"
lab var Longitud "Longitude"
lab var area "Area"
lab var pop "Population (1000)"
lab var CountyAdm "Regional capital"
lab var riksveg "National roads (km)"

lab var dmentions_anyparty "Hometown mentioned in parliament"
lab var dmentions "Hometown mentioned in parliament by legislator from same party"
lab var support_diff "Local party support (rel. to rest of district, current election)"
lab var support_diff_change "$ \Delta$ Local party support (rel. to rest of district, next election)"
lab var turnout_diff "Local voter turnout (rel. to rest of district, current election)"
lab var turnout_diff_change "$ \Delta$ Local voter turnout (rel. to rest of district, next election)"
lab var rank1_knr_next "Local candidate ranked first (next election)"
lab var rank2_knr_next "Local candidate ranked second (next election)"

foreach var in dseat_knr dseat_pknr {
replace `var'=`var'*(-1)+2
}

eststo clear
estpost summarize meterCAP_curr d_govempl cgfund_inv turnout_diff turnout_diff_change dmentions_anyparty Latitude Longitude area pop CountyAdm riksveg if dseat_knr==2&party=="dna"
eststo a
estpost summarize meterCAP_curr d_govempl cgfund_inv turnout_diff turnout_diff_change dmentions_anyparty Latitude Longitude area pop CountyAdm riksveg if dseat_knr==1&party=="dna"
eststo b
estpost ttest meterCAP_curr d_govempl cgfund_inv turnout_diff turnout_diff_change dmentions_anyparty Latitude Longitude area pop CountyAdm riksveg if party=="dna", by(dseat_knr)
eststo x
estpost summarize meterCAP_curr d_govempl cgfund_inv turnout_diff turnout_diff_change dmentions_anyparty Latitude Longitude area pop CountyAdm riksveg if party=="dna"
eststo n
esttab a b x n using Tab\TabA1.tex, replace style(tex) ///
noobs nonumbers mtitles("No seat" "Seat" "Difference" "N") collabels(none) nostar label gaps  ///
order(turnout_diff turnout_diff_change dmentions_anyparty meterCAP_curr d_govempl cgfund_inv) ///
cells("mean(fmt(3) pattern(1 1 0 0)) b(star fmt(3) pattern(0 0 1 0)) count(fmt(%8.0gc) pattern(0 0 0 1))" "sd(par fmt(3) pattern(1 1 0 0)) se(par fmt(3) pattern(0 0 1 0))") ///
prehead("\begin{tabular}{l*{4}{c}}" "\multicolumn{4}{c}{\textbf{Panel A: Municipality-level outcomes}} \\" "\hline") posthead(\hline) postfoot("\hline \\")


eststo clear
estpost summarize dmentions support_diff support_diff_change rank1_knr_next rank2_knr_next if dseat_pknr==2
eststo a
estpost summarize dmentions support_diff support_diff_change rank1_knr_next rank2_knr_nex if dseat_pknr==1
eststo b
estpost ttest dmentions support_diff support_diff_change rank1_knr_next rank2_knr_next, by(dseat_pknr)
eststo x
estpost summarize dmentions support_diff support_diff_change rank1_knr_next rank2_knr_next
eststo n
esttab a b x n using Tab\TabA1.tex, append style(tex) ///
noobs nonumbers mtitles("No seat" "Seat" "Difference" "N") collabels(none) nostar label gaps ///
order(support_diff support_diff_change rank1_knr_next rank2_knr_next dmentions) ///
cells("mean(fmt(3) pattern(1 1 0 0)) b(star fmt(3) pattern(0 0 1 0)) count(fmt(%8.0gc) pattern(0 0 0 1))" "sd(par fmt(3) pattern(1 1 0 0)) se(par fmt(3) pattern(0 0 1 0))") ///
prehead("\multicolumn{4}{c}{\textbf{Panel B: Party-municipality-level outcomes}} \\" "\hline") posthead(\hline) postfoot("\hline" "\end{tabular}")

*copy Tab\TabA1.tex ..\tables\descriptives_knr.tex, replace


*******************************************************************************
******************************* FIGURE B2 *************************************
*******************************************************************************

*version 13.0

cd C:\Users\zruan\Documents\qjps_19147_supp\Fig\gph\

replace govempl=10 if govempl>10 & govempl!=.
replace d_govempl=5 if d_govempl>5 & d_govempl!=.
replace d_govempl=-5 if d_govempl<-5 & d_govempl!=.
hist govempl if party=="dna", freq width(0.5) start(0) bfcolor(gs10) blcolor(gs6) lalign(center) subtitle("Positions per 100 inhabitants") xtitle("") ylabel(0(500)1500) yscale(range(0 1750)) ytitle("") graphregion(color(white)) xlabel(0(1)10)
graph save hist_govempl.gph, replace
hist d_govempl if party=="dna", freq width(0.5) start(-5) bfcolor(gs10) blcolor(gs6) lalign(center) subtitle("Increase per 100 inhabitants") xtitle("") ylabel(0(500)1500) yscale(range(0 1750)) ytitle("") graphregion(color(white)) xlabel(-5(1)5)
graph save hist_d_govempl.gph, replace

graph combine hist_govempl.gph hist_d_govempl.gph, xsize(7) iscale(*1.3) graphregion(color(white))

cd C:\Users\zruan\Documents\qjps_19147_supp\

*graph export ..\figures\hist_govempl.pdf, replace
graph export Fig\FigB2.pdf, replace
